Github - velruse.providers.github — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# Github - `velruse.providers.github`

The Github provider combines authentication with OAuth authorization. It requires a Github Application to have been created to use.

Github Links:

- Register a New Github Application
- Github OAuth API

## Settings

`consumer_key`
  github application consumer key
`consumer_secret`
  github application secret
`scope`
  github application scope

## POST Parameters

Complete Example:

    <form action="/velruse/github/login" method="post">
        <input type="submit" value="Login with Github" />
    </form>

## Pyramid API

Github Authentication Views

class `GithubAuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  Bases: `velruse.AuthenticationComplete`

  Github auth complete

`includeme`(config)

`add_github_login`(config, consumer_key, consumer_secret, scope=None, login_path='/login/github', callback_path='/login/github/callback', secure=True, domain='github.com', name='github')

  Add a Github login provider to the application.

`add_github_login_from_settings`(config, prefix='velruse.github.')

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »